@@ -57,7 +57,7 @@ irc_info_create_string_with_pointer (char **string, void *pointer)
         *string = malloc (64);
         if (*string)
         {
-            snprintf (*string, 64, "%p", pointer);
+            snprintf (*string, 64, "0x%lx", (unsigned long)pointer);
         }
     }
 }
